@@ -1,8 +1,4 @@
 #line 5 "finduses.nw"
-static char rcsid[] = "$Id: finduses.nw,v 1.22 2008/10/06 01:03:05 nr Exp nr $";
-static char rcsname[] = "$Name: v2_12 $";
-static struct keepalive { char *s; struct keepalive *p; } keepalive[] =
-  { {rcsid, keepalive}, {rcsname, keepalive} }; /* avoid warnings */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -11,26 +7,26 @@ static struct keepalive { char *s; struct keepalive *p; } keepalive[] =
 #include "match.h"
 #include "getline.h"
 #include "recognize.h"
-#line 23 "finduses.nw"
+#line 19 "finduses.nw"
 static Recognizer nwindex;
 #define ALPHANUM "_'@ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789#"
 #define SYMBOLS "!%^&*-+:=|~<>./?`"
 /* note $ and \ both delimiters */
-#line 31 "finduses.nw"
+#line 27 "finduses.nw"
 static int showquotes = 1;
-#line 97 "finduses.nw"
+#line 93 "finduses.nw"
 typedef struct line_and_outfile {
     char *line;
     FILE *out;
 } LineOut;
-#line 66 "finduses.nw"
+#line 62 "finduses.nw"
 static void read_ids(FILE *in);
-#line 102 "finduses.nw"
+#line 98 "finduses.nw"
 static void add_use_markers(FILE *in, FILE *out);
-#line 154 "finduses.nw"
+#line 150 "finduses.nw"
 static void write_index_use(void *closure, char *id, char *instance);
 static char *emit_up_to(FILE *f, char *s, char *limit);
-#line 35 "finduses.nw"
+#line 31 "finduses.nw"
 int main(int argc, char **argv) {
     FILE *fp;
     int i;
@@ -44,18 +40,18 @@ int main(int argc, char **argv) {
     nwindex = new_recognizer(ALPHANUM, SYMBOLS);
     if (i == argc) {
        
-#line 77 "finduses.nw"
+#line 73 "finduses.nw"
 {   FILE *tmp = tmpfile();
     char *line;
     if (tmp == NULL) 
-#line 157 "finduses.nw"
+#line 153 "finduses.nw"
 errormsg(Fatal, "%s: couldn't open temporary file\n", progname);
-#line 80 "finduses.nw"
+#line 76 "finduses.nw"
     while ((line = getline_nw(stdin)) != NULL) {
         if (fputs(line, tmp) == EOF) 
-#line 159 "finduses.nw"
+#line 155 "finduses.nw"
 errormsg(Fatal, "%s: error writing temporary file\n", progname);
-#line 82 "finduses.nw"
+#line 78 "finduses.nw"
         if (is_index(line, "defn")) {
             if (line[strlen(line)-1] == '\n') line[strlen(line)-1] = 0;
             add_ident(nwindex, line+1+5+1+4+1);
@@ -70,10 +66,10 @@ errormsg(Fatal, "%s: error writing temporary file\n", progname);
     stop_adding(nwindex);
     add_use_markers(tmp, stdout);
 }
-#line 48 "finduses.nw"
+#line 44 "finduses.nw"
     } else {
        
-#line 58 "finduses.nw"
+#line 54 "finduses.nw"
 for (; i < argc; i++)
     if ((fp=fopen(argv[i],"r"))==NULL)
         errormsg(Error, "%s: couldn't open file %s\n", progname, argv[i]);
@@ -81,14 +77,14 @@ for (; i < argc; i++)
         read_ids(fp);
         fclose(fp);
     }
-#line 50 "finduses.nw"
+#line 46 "finduses.nw"
        stop_adding(nwindex);
        add_use_markers(stdin, stdout);
     }
     nowebexit(NULL);
-    return errorlevel;          /* slay warning */
+    return errorlevel;                /* slay warning */
 }
-#line 68 "finduses.nw"
+#line 64 "finduses.nw"
 static void read_ids(FILE *in) {
     char *line;
     while ((line = getline_nw(in)) != NULL) {
@@ -96,7 +92,7 @@ static void read_ids(FILE *in) {
         add_ident(nwindex, line);
     }
 }
-#line 104 "finduses.nw"
+#line 100 "finduses.nw"
 static void add_use_markers(FILE *in, FILE *out) {
     char *line;
     int incode = 0;
@@ -116,14 +112,14 @@ static void add_use_markers(FILE *in, FILE *out) {
             fprintf(out, "%s", line);
     }       
 }
-#line 135 "finduses.nw"
+#line 131 "finduses.nw"
 static void write_index_use(void *closure, char *id, char *instance) {
   LineOut *info = (LineOut *) closure;
   info->line = emit_up_to(info->out, info->line, instance);
   fprintf(info->out, "@index use %s\n", id);
   info->line = emit_up_to(info->out, info->line, instance + strlen(id));
 }
-#line 142 "finduses.nw"
+#line 138 "finduses.nw"
 static char *emit_up_to(FILE *f, char *s, char *limit) {
   if (s < limit) {
     char saved = *limit;
