@@ -1,6 +1,4 @@
 #line 17 "getline.nw"
-static char rcsid[] = "$Id: getline.nw,v 2.24 2008/10/06 01:03:05 nr Exp nr $";
-static char rcsname[] = "$Name: v2_12 $";
 #define START_SIZE 128                  /* initial buffer size */
 
 #include <stdio.h>
@@ -13,21 +11,21 @@ static char rcsname[] = "$Name: v2_12 $";
 static char *buf1 = NULL, *buf2 = NULL; /* lines without, with tabs expanded */
 static int buf_size = START_SIZE;       /* size of both buffers if non-NULL */
 
-#line 44 "getline.nw"
+#line 42 "getline.nw"
 void new_buffers(void) {
     checkptr(buf1 = (char *) realloc(buf1, buf_size));
     checkptr(buf2 = (char *) realloc(buf2, buf_size));
 }
-#line 49 "getline.nw"
+#line 47 "getline.nw"
 char *getline_nw (FILE *fp) {
 
     
-#line 86 "getline.nw"
+#line 82 "getline.nw"
 if (buf1==NULL) {
     checkptr(buf1 = (char *) malloc (buf_size));
     checkptr(buf2 = (char *) malloc (buf_size));
 }
-#line 52 "getline.nw"
+#line 50 "getline.nw"
     
     buf1=fgets(buf1, buf_size, fp);
     if (buf1==NULL) return buf1; /* end of file */
@@ -37,23 +35,21 @@ if (buf1==NULL) {
         if (fgets(buf1+strlen(buf1),buf_size-strlen(buf1),fp)==NULL)
             return buf1; /* end of file */
     }
-    (void)rcsid; /* avoid a warning */
-    (void)rcsname; /* avoid a warning */
     return buf1;
 }
-#line 66 "getline.nw"
+#line 62 "getline.nw"
 char *getline_expand (FILE *fp) {
     char *s, *t;
     int width;
 
     if (getline_nw(fp)==NULL) return NULL;
     
-#line 91 "getline.nw"
+#line 87 "getline.nw"
 if (columnwidth(buf1) > buf_size - 1) {
     while (columnwidth(buf1) > buf_size - 1) buf_size *= 2;
     new_buffers();
 }
-#line 72 "getline.nw"
+#line 68 "getline.nw"
     s = buf1; t = buf2; width=0;
     while (*s)
         if (*s=='\t' && tabsize > 0) {
