@@ -1,6 +1,4 @@
 #line 50 "modules.nw"
-static char rcsid[] = "$Id: modules.nw,v 2.26 2008/10/06 01:03:05 nr Exp nr $";
-static char rcsname[] = "$Name: v2_12 $";
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -11,15 +9,15 @@ static char rcsname[] = "$Name: v2_12 $";
 #include "columns.h"
 #include "strsave.h"
 
-#line 112 "modules.nw"
+#line 108 "modules.nw"
 static struct modpart *
 newmodpart(int type, char *s, Location *loc);   /* create a new module part */
 
 static
 void append(Module mp, struct modpart *p);
-#line 229 "modules.nw"
+#line 225 "modules.nw"
 static int seekcycle(Module mp, Parent parent);
-#line 134 "modules.nw"
+#line 130 "modules.nw"
 static char *lastfilename = 0;
 static int lastlineno = -1;
 #line 41 "modules.nw"
@@ -31,12 +29,12 @@ Module newmodule (char *modname) {
     p->head = p->tail = NULL;
     return p;
 }
-#line 74 "modules.nw"
+#line 72 "modules.nw"
 void add_part (Module mp, char *s, Parttype type, Location *loc) {
     struct modpart *p = newmodpart(type,s,loc);
     append (mp,p);
 }
-#line 79 "modules.nw"
+#line 77 "modules.nw"
 static struct modpart *
 newmodpart(int type, char *s, Location *loc) {
     struct modpart *p = (struct modpart *) malloc (sizeof (struct modpart));
@@ -45,20 +43,18 @@ newmodpart(int type, char *s, Location *loc) {
     if (s) {
         p->contents = strsave(s);
         
-#line 106 "modules.nw"
+#line 102 "modules.nw"
 { int k = strlen(p->contents)-1;
   if (p->contents[k] == '\n') p->contents[k] = '\0';
   else impossible("input line doesn't end with newline");
 }
-#line 87 "modules.nw"
+#line 85 "modules.nw"
     }
     if (loc) p->loc = *loc;
     p->next = NULL;
-    (void)rcsid; /* avoid a warning */
-    (void)rcsname; /* avoid a warning */
     return p;
 }
-#line 95 "modules.nw"
+#line 91 "modules.nw"
 static
 void append(Module mp, struct modpart *p) {
     /* append p to mp's list of modparts */
@@ -69,12 +65,12 @@ void append(Module mp, struct modpart *p) {
         mp->tail = p;
     }
 }
-#line 139 "modules.nw"
+#line 135 "modules.nw"
 void resetloc(void) {
   lastfilename = 0;
   lastlineno = -1;
 }
-#line 147 "modules.nw"
+#line 143 "modules.nw"
 int expand (Module mp, int indent, int partial_distance, Parent parent,  
             char *locformat, FILE *out) {
     struct modpart *p;
@@ -83,22 +79,22 @@ int expand (Module mp, int indent, int partial_distance, Parent parent,
     struct parent thismodule; /* the value only matters when we're expanding a module */
 
     
-#line 221 "modules.nw"
+#line 217 "modules.nw"
 thismodule.this = mp;
 thismodule.parent = parent;
-#line 155 "modules.nw"
+#line 151 "modules.nw"
     
-#line 224 "modules.nw"
+#line 220 "modules.nw"
 if (seekcycle(mp, parent)) {
     errormsg(Error, "<<%s>>", mp->name);
     return Error;
 }
 
-#line 157 "modules.nw"
+#line 153 "modules.nw"
     for (p=mp->head; p!=NULL; p=p->next) {
         switch (p->ptype) {
             case STRING:  
-#line 178 "modules.nw"
+#line 174 "modules.nw"
 if (*(p->contents) != '\0') {
     if (*locformat) {
         if (printloc(out,locformat,p->loc,partial_distance) && (p != mp->head))
@@ -110,10 +106,10 @@ if (*(p->contents) != '\0') {
     fprintf(out,"%s",p->contents);
     partial_distance = limitcolumn(p->contents, partial_distance);
 }
-#line 159 "modules.nw"
+#line 155 "modules.nw"
                                             ;  break;
             case MODULE:  
-#line 203 "modules.nw"
+#line 199 "modules.nw"
 newmod = lookup(p->contents);
 if (newmod==NULL) {
     errormsg (Error, "undefined chunk name: <<%s>>", p->contents);
@@ -130,21 +126,21 @@ if (newmod==NULL) {
 }
 partial_distance = limitcolumn(p->contents, partial_distance + 2) + 2; 
                                 /* account for surrounding brackets */
-#line 160 "modules.nw"
+#line 156 "modules.nw"
                                              ; break;
             case NEWLINE: 
-#line 190 "modules.nw"
+#line 186 "modules.nw"
 partial_distance = 0;
 putc('\n', out);
 lastlineno++;
-#line 161 "modules.nw"
+#line 157 "modules.nw"
                                              ; break;
             default: impossible("bad part type");
         }
     }
     return error;
 }
-#line 231 "modules.nw"
+#line 227 "modules.nw"
 static int seekcycle(Module mp, Parent parent) {
     if (parent == NULL) {
         return 0;
@@ -157,14 +153,14 @@ static int seekcycle(Module mp, Parent parent) {
         return 0;
     }
 }
-#line 253 "modules.nw"
+#line 249 "modules.nw"
 int printloc(FILE *fp, char *fmt, Location loc, int partial) {
     char *p;
     if (*fmt
     && (loc.filename!=lastfilename || lastlineno != loc.lineno)) {
         if (partial) putc('\n',fp);
         
-#line 265 "modules.nw"
+#line 261 "modules.nw"
 for (p = fmt; *p; p++) {
     if (*p == '%') {
         switch (*++p) {
@@ -179,35 +175,35 @@ for (p = fmt; *p; p++) {
                           p += 2;
                         } else
                           
-#line 285 "modules.nw"
+#line 281 "modules.nw"
 { static int complained = 0;
   if (!complained) {
     errormsg(Error,"Bad format sequence ``%%%c'' in -L%s",*p,fmt);
     complained = 1;
   }
 }
-#line 279 "modules.nw"
+#line 275 "modules.nw"
                       break;            
             default:  
-#line 285 "modules.nw"
+#line 281 "modules.nw"
 { static int complained = 0;
   if (!complained) {
     errormsg(Error,"Bad format sequence ``%%%c'' in -L%s",*p,fmt);
     complained = 1;
   }
 }
-#line 280 "modules.nw"
+#line 276 "modules.nw"
                                                                 break;
         }
     } else putc(*p, fp);
 }
-#line 259 "modules.nw"
+#line 255 "modules.nw"
         lastfilename = loc.filename;
         lastlineno = loc.lineno;
         return 1;
     } else return 0;
 }
-#line 311 "modules.nw"
+#line 307 "modules.nw"
 void remove_final_newline (Module mp) {
         /* remove trailing newline that must be in module */
     if (mp->tail==NULL) /* module has no text */
